@@ -1,6 +1,6 @@
-import json
 import os
 import threading
+import warnings
 from typing import Dict, Optional
 from urllib.parse import urlencode
 
@@ -62,7 +62,9 @@ class OpaClient(BaseClient):
 		session.mount("https://", adapter)
 
 		if self.ssl:
-			session.verify = self.cert
+			session.verify = self.ssl
+		if self.cert:
+			session.cert = self.cert
 
 		return session
 
@@ -202,7 +204,9 @@ class OpaClient(BaseClient):
 		    bool: True if the policy was successfully updated.
 		"""
 		if not os.path.isfile(filepath):
-			raise FileError(f"'{filepath}' is not a valid file")
+			raise FileError(
+				"file_not_found", f"'{filepath}' is not a valid file"
+			)
 
 		with open(filepath, "r", encoding="utf-8") as file:
 			policy_str = file.read()
@@ -300,7 +304,9 @@ class OpaClient(BaseClient):
 		policy_raw = policy.get("result", {}).get("raw", "")
 
 		if not policy_raw:
-			raise PolicyNotFoundError("Policy content is empty")
+			raise PolicyNotFoundError(
+				"resource_not_found", "Policy content is empty"
+			)
 
 		full_path = os.path.join(path or "", filename)
 
@@ -309,7 +315,9 @@ class OpaClient(BaseClient):
 				file.write(policy_raw)
 			return True
 		except OSError as e:
-			raise PathNotFoundError(f"Failed to write to '{full_path}'") from e
+			raise PathNotFoundError(
+				"path_not_found", f"Failed to write to '{full_path}'"
+			) from e
 
 	def get_policy(self, policy_name: str) -> dict:
 		"""
@@ -384,6 +392,11 @@ class OpaClient(BaseClient):
 		Returns:
 		    dict: The result of the permission check.
 		"""
+		warnings.warn(
+			"check_permission is deprecated and will be removed in a future release. Use `query_rule` instead.",
+			DeprecationWarning,
+			stacklevel=2
+    	)
 		policy = self.get_policy(policy_name)
 		ast = policy.get("result", {}).get("ast", {})
 		package_path = "/".join(
@@ -395,7 +408,8 @@ class OpaClient(BaseClient):
 
 		if rule_name not in rules:
 			raise CheckPermissionError(
-				f"Rule '{rule_name}' not found in policy '{policy_name}'"
+				"resource_not_found",
+				f"Rule '{rule_name}' not found in policy '{policy_name}'",
 			)
 
 		url = f"{self.root_url}/{package_path}/{rule_name}"
@@ -456,89 +470,6 @@ class OpaClient(BaseClient):
 		response.raise_for_status()
 		return response.json()
 
-	# # Property methods for read-only access to certain attributes
-	# @property
-	# def host(self) -> str:
-	#     return self._host
-
-	# @host.setter
-	# def host(self, value: str):
-	#     self._host = value
-
-	# @property
-	# def port(self) -> int:
-	#     return self._port
-
-	# @port.setter
-	# def port(self, value: int):
-	#     if not isinstance(value, int):
-	#         raise TypeError('Port must be an integer')
-	#     self._port = value
-
-	# @property
-	# def version(self) -> str:
-	#     return self._version
-
-	# @version.setter
-	# def version(self, value: str):
-	#     self._version = value
-
-	# @property
-	# def schema(self) -> str:
-	#     return self._schema
-
-	# @schema.setter
-	# def schema(self, value: str):
-	#     self._schema = value
-
-	# @property
-	# def root_url(self) -> str:
-	#     return self._root_url
-
-	# @root_url.setter
-	# def root_url(self, value: str):
-	#     self._root_url = value
-
-	# @property
-	# def ssl(self) -> bool:
-	#     return self._ssl
-
-	# @ssl.setter
-	# def ssl(self, value: bool):
-	#     self._ssl = value
-
-	# @property
-	# def cert(self) -> Optional[str]:
-	#     return self._cert
-
-	# @cert.setter
-	# def cert(self, value: Optional[str]):
-	#     self._cert = value
-
-	# @property
-	# def headers(self) -> dict:
-	#     return self._headers
-
-	# @headers.setter
-	# def headers(self, value: dict):
-	#     self._headers = value
-
-	# @property
-	# def retries(self) -> int:
-	#     return self._retries
-
-	# @retries.setter
-	# def retries(self, value: int):
-	#     self._retries = value
-
-	# @property
-	# def timeout(self) -> float:
-	#     return self._timeout
-
-	# @timeout.setter
-	# def timeout(self, value: float):
-	#     self._timeout = value
-
 
 # Example usage:
 if __name__ == "__main__":
